@@ -254,11 +254,11 @@ int main(int argc, char *argv[])
     qmlRegisterType<PlayerModel>("pentobi", 1, 0, "PlayerModel");
     qmlRegisterType<RatingModel>("pentobi", 1, 0, "RatingModel");
     qmlRegisterType<SyncSettings>("pentobi", 1, 0, "SyncSettings");
-    qmlRegisterInterface<AnalyzeGameElement>("AnalyzeGameElement");
-    qmlRegisterInterface<GameMove>("GameModelMove");
-    qmlRegisterInterface<PieceModel>("PieceModel");
+    qmlRegisterUncreatableType<AnalyzeGameElement>(
+                "pentobi", 1, 0, "AnalyzeGameElement", {});
+    qmlRegisterUncreatableType<GameMove>("pentobi", 1, 0, "GameMove", {});
+    qmlRegisterUncreatableType<PieceModel>("pentobi", 1, 0, "PieceModel", {});
 #ifndef Q_OS_ANDROID
-    // Qt translations needed for QCommandLineParser
     QTranslator qtTranslator;
     qtTranslator.load(
                 "qt_" + QLocale::system().name(),
