@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="de">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -888,6 +886,10 @@
         <source>Pentobi failed to generate a move.</source>
         <translation>Pentobi konnte keinen Zug generieren.</translation>
     </message>
+    <message>
+        <source>Press back again to exit</source>
+        <translation>Zum Beenden erneut Zurück drücken</translation>
+    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -895,31 +897,6 @@
         <source>Computer</source>
         <translation>Computer</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
-        <translation>Z</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
 </context>
 <context>
     <name>MenuEdit</name>
@@ -927,16 +904,6 @@
         <source>Edit</source>
         <translation>Bearbeiten</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
     <message>
         <source>Make Main Variation</source>
         <translation>Zu Hauptvariante machen</translation>
@@ -946,93 +913,43 @@
         <extracomment>Short for Move Variation Up</extracomment>
         <translation>Variante nach oben</translation>
     </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
         <translation>Variante nach unten</translation>
     </message>
-    <message>
-        <source>W</source>
-        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Delete Variations</source>
         <translation>Varianten löschen</translation>
     </message>
-    <message>
-        <source>D</source>
-        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
     <message>
         <source>Truncate</source>
         <translation>Abschneiden</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Truncate Children</source>
         <translation>Kindknoten abschneiden</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
     <message>
         <source>Keep Position</source>
         <translation>Brettstellung behalten</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
     <message>
         <source>Keep Subtree</source>
         <translation>Teilbaum behalten</translation>
     </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
     <message>
         <source>Setup Mode</source>
         <translation>Stellungsaufbau</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Next Color</source>
         <translation>Nächste Farbe</translation>
     </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
     <message>
         <source>Annotation…</source>
         <translation>Annotierung …</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
     <message>
         <source>Made main variation</source>
         <translation>Zu Hauptvariante gemacht</translation>
@@ -1044,21 +961,6 @@
         <source>Export</source>
         <translation>Exportieren</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
-        <translation>G</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Image…</source>
         <translation>Grafik …</translation>
@@ -1074,74 +976,14 @@
         <source>Game</source>
         <translation>Spiel</translation>
     </message>
-    <message>
-        <source>G</source>
-        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
-        <translation>W</translation>
-    </message>
     <message>
         <source>Game Variant…</source>
         <translation>Spielvariante …</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>I</source>
-        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
-        <translation>Z</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
-        <translation>f</translation>
-    </message>
     <message>
         <source>Open Clipboard</source>
         <translation>Zwischenablage öffnen</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
-    <message>
-        <source>Q</source>
-        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1149,31 +991,6 @@
         <source>Go</source>
         <translation>Gehe zu</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
-        <translation>G</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
 </context>
 <context>
     <name>MenuHelp</name>
@@ -1181,34 +998,14 @@
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
-    <message>
-        <source>H</source>
-        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>About Pentobi</source>
         <translation>Über Pentobi</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
     <message>
         <source>Report Bug</source>
         <translation>Fehler melden</translation>
     </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
 </context>
 <context>
     <name>MenuItem</name>
@@ -1229,26 +1026,11 @@
         <source>Open Recent</source>
         <translation>Zuletzt benutzt</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
-    <message>
-        <source>%1. %2</source>
-        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
-        <translation>%1. %2</translation>
-    </message>
     <message>
         <source>Clear List</source>
         <extracomment>Menu item for clearing the recent files list</extracomment>
         <translation>Liste leeren</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
 </context>
 <context>
     <name>MenuTools</name>
@@ -1256,47 +1038,18 @@
         <source>Tools</source>
         <translation>Extras</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
-        <translation>X</translation>
-    </message>
     <message>
         <source>Rating</source>
         <translation>Wertung</translation>
     </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
-        <translation>W</translation>
-    </message>
     <message>
         <source>Clear Rating</source>
         <translation>Wertung löschen</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
-    <message>
-        <source>Analyze Game</source>
-        <translation type="vanished">Spiel analysieren</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Clear Analysis</source>
         <translation>Analyse löschen</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
     <message>
         <source>Analyze Game…</source>
         <translation>Spiel analysieren …</translation>
@@ -1308,26 +1061,6 @@
         <source>View</source>
         <translation>Ansicht</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
     <message>
         <source>Appearance</source>
         <translation>Erscheinungsbild</translation>
@@ -1336,11 +1069,6 @@
         <source>Toolbar</source>
         <translation>Werkzeugleiste</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
-        <translation>W</translation>
-    </message>
 </context>
 <context>
     <name>MoveAnnotationDialog</name>
@@ -1505,45 +1233,6 @@
         <source>Recent development:</source>
         <translation>Aktuelle Entwicklung:</translation>
     </message>
-    <message>
-        <source>Game</source>
-        <translation type="vanished">Spiel</translation>
-    </message>
-    <message>
-        <source>Result</source>
-        <translation type="vanished">Ergebnis</translation>
-    </message>
-    <message>
-        <source>Win</source>
-        <extracomment>Result of rated game is a win</extracomment>
-        <translation type="vanished">Gewinn</translation>
-    </message>
-    <message>
-        <source>Loss</source>
-        <extracomment>Result of rated game is a loss</extracomment>
-        <translation type="vanished">Verlust</translation>
-    </message>
-    <message>
-        <source>Tie</source>
-        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
-        <translation type="vanished">Unentsch.</translation>
-    </message>
-    <message>
-        <source>Level</source>
-        <translation type="vanished">Stufe</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation type="vanished">Ihre Farbe</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation type="vanished">Datum</translation>
-    </message>
-    <message>
-        <source>Open Game %1</source>
-        <translation type="vanished">Spiel %1 öffnen</translation>
-    </message>
 </context>
 <context>
     <name>SaveDialog</name>
@@ -1738,4 +1427,4 @@
         <translation>Zu viele Argumente</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
