@@ -888,6 +888,10 @@
         <source>Pentobi failed to generate a move.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Press back again to exit</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -895,31 +899,6 @@
         <source>Computer</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuEdit</name>
@@ -927,16 +906,6 @@
         <source>Edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Make Main Variation</source>
         <translation type="unfinished"></translation>
@@ -946,93 +915,43 @@
         <extracomment>Short for Move Variation Up</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>W</source>
-        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Delete Variations</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>D</source>
-        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Truncate</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Truncate Children</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Keep Position</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Keep Subtree</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Setup Mode</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Next Color</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Annotation…</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Made main variation</source>
         <translation type="unfinished"></translation>
@@ -1044,21 +963,6 @@
         <source>Export</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Image…</source>
         <translation type="unfinished"></translation>
@@ -1074,74 +978,14 @@
         <source>Game</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>G</source>
-        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Game Variant…</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>I</source>
-        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Open Clipboard</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Q</source>
-        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1149,31 +993,6 @@
         <source>Go</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuHelp</name>
@@ -1181,34 +1000,14 @@
         <source>Help</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>H</source>
-        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>About Pentobi</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Report Bug</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuItem</name>
@@ -1229,26 +1028,11 @@
         <source>Open Recent</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>%1. %2</source>
-        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Clear List</source>
         <extracomment>Menu item for clearing the recent files list</extracomment>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MenuTools</name>
@@ -1256,43 +1040,18 @@
         <source>Tools</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Rating</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Clear Rating</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Clear Analysis</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Analyze Game…</source>
         <translation type="unfinished"></translation>
@@ -1304,26 +1063,6 @@
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Appearance</source>
         <translation type="unfinished"></translation>
@@ -1332,11 +1071,6 @@
         <source>Toolbar</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>MoveAnnotationDialog</name>
@@ -1501,6 +1235,10 @@
         <source>Recent development:</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Open Game %1</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>SaveDialog</name>
