@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="es">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="es" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -888,6 +886,10 @@
         <source>Pentobi failed to generate a move.</source>
         <translation>Pentobi no pudo generar un movimiento.</translation>
     </message>
+    <message>
+        <source>Press back again to exit</source>
+        <translation type="unfinished"/>
+    </message>
 </context>
 <context>
     <name>MenuComputer</name>
@@ -895,31 +897,6 @@
         <source>Computer</source>
         <translation>Máquina</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
-        <translation>D</translation>
-    </message>
 </context>
 <context>
     <name>MenuEdit</name>
@@ -927,16 +904,6 @@
         <source>Edit</source>
         <translation>Editar</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
     <message>
         <source>Make Main Variation</source>
         <translation>Convertir en variación principal</translation>
@@ -946,93 +913,43 @@
         <extracomment>Short for Move Variation Up</extracomment>
         <translation>Subir variación</translation>
     </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
         <translation>Bajar variación</translation>
     </message>
-    <message>
-        <source>W</source>
-        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
     <message>
         <source>Delete Variations</source>
         <translation>Eliminar variaciones</translation>
     </message>
-    <message>
-        <source>D</source>
-        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
     <message>
         <source>Truncate</source>
         <translation>Eliminar</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
     <message>
         <source>Truncate Children</source>
         <translation>Eliminar descendientes</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
     <message>
         <source>Keep Position</source>
         <translation>Conservar posición</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>Keep Subtree</source>
         <translation>Conservar subárbol</translation>
     </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Setup Mode</source>
         <translation>Modo configuración</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Next Color</source>
         <translation>Siguiente color</translation>
     </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
     <message>
         <source>Annotation…</source>
         <translation>Valoración...</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Made main variation</source>
         <translation>Se ha convertido en variación principal</translation>
@@ -1044,21 +961,6 @@
         <source>Export</source>
         <translation>Exportar</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Image…</source>
         <translation>Imagen...</translation>
@@ -1074,74 +976,14 @@
         <source>Game</source>
         <translation>Partida</translation>
     </message>
-    <message>
-        <source>G</source>
-        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Game Variant…</source>
         <translation>Variante de juego...</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>I</source>
-        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
-        <translation>I</translation>
-    </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
-        <translation>D</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Open Clipboard</source>
         <translation>Abrir portapapeles</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
-        <translation>G</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
-    <message>
-        <source>Q</source>
-        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1149,31 +991,6 @@
         <source>Go</source>
         <translation>Ir a</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
-        <translation>I</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
 </context>
 <context>
     <name>MenuHelp</name>
@@ -1181,34 +998,14 @@
         <source>Help</source>
         <translation>Ayuda</translation>
     </message>
-    <message>
-        <source>H</source>
-        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>About Pentobi</source>
         <translation>Acerca de Pentobi</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Report Bug</source>
         <translation>Informe de errores</translation>
     </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
 </context>
 <context>
     <name>MenuItem</name>
@@ -1229,26 +1026,11 @@
         <source>Open Recent</source>
         <translation>Abrir reciente</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
-    <message>
-        <source>%1. %2</source>
-        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
-        <translation>%1. %2</translation>
-    </message>
     <message>
         <source>Clear List</source>
         <extracomment>Menu item for clearing the recent files list</extracomment>
         <translation>Borrar lista</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
 </context>
 <context>
     <name>MenuTools</name>
@@ -1256,47 +1038,18 @@
         <source>Tools</source>
         <translation>Herramientas</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
     <message>
         <source>Rating</source>
         <translation>Selección de nivel</translation>
     </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Clear Rating</source>
         <translation>Borrar nivel</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
-    <message>
-        <source>Analyze Game</source>
-        <translation type="vanished">Analizar partida</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Clear Analysis</source>
         <translation>Borrar análisis</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Analyze Game…</source>
         <translation>Analizar partida...</translation>
@@ -1308,26 +1061,6 @@
         <source>View</source>
         <translation>Vista</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
     <message>
         <source>Appearance</source>
         <translation>Apariencia</translation>
@@ -1336,11 +1069,6 @@
         <source>Toolbar</source>
         <translation>Barra de herramientas</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
 </context>
 <context>
     <name>MoveAnnotationDialog</name>
@@ -1505,44 +1233,9 @@
         <source>Recent development:</source>
         <translation>Novedad reciente:</translation>
     </message>
-    <message>
-        <source>Game</source>
-        <translation type="vanished">Partida</translation>
-    </message>
-    <message>
-        <source>Result</source>
-        <translation type="vanished">Resultado</translation>
-    </message>
-    <message>
-        <source>Win</source>
-        <extracomment>Result of rated game is a win</extracomment>
-        <translation type="vanished">Victoria</translation>
-    </message>
-    <message>
-        <source>Loss</source>
-        <extracomment>Result of rated game is a loss</extracomment>
-        <translation type="vanished">Derrota</translation>
-    </message>
-    <message>
-        <source>Tie</source>
-        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
-        <translation type="vanished">Empate</translation>
-    </message>
-    <message>
-        <source>Level</source>
-        <translation type="vanished">Nivel</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation type="vanished">Su color</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation type="vanished">Fecha</translation>
-    </message>
     <message>
         <source>Open Game %1</source>
-        <translation type="vanished">Abrir partida %1</translation>
+        <translation>Abrir partida %1</translation>
     </message>
 </context>
 <context>
@@ -1738,4 +1431,4 @@
         <translation>Demasiados argumentos</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
