@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="nb_NO">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="nb_NO" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -17,96 +15,6 @@
         <translation>Pentobi %1</translation>
     </message>
 </context>
-<context>
-    <name>Actions</name>
-    <message>
-        <source>Main Variation</source>
-        <translation type="vanished">Hovedvariasjon</translation>
-    </message>
-    <message>
-        <source>Beginning of Branch</source>
-        <translation type="vanished">Begynnelse av forgreining</translation>
-    </message>
-    <message>
-        <source>Settings…</source>
-        <extracomment>Menu item Computer/Settings</extracomment>
-        <translation type="vanished">Innstillinger</translation>
-    </message>
-    <message>
-        <source>Find Move</source>
-        <translation type="vanished">Finn trekk</translation>
-    </message>
-    <message>
-        <source>Next Comment</source>
-        <translation type="vanished">Neste kommentar</translation>
-    </message>
-    <message>
-        <source>Fullscreen</source>
-        <translation type="vanished">Fullskjermsvisning</translation>
-    </message>
-    <message>
-        <source>Move Number…</source>
-        <translation type="vanished">Trekknummer…</translation>
-    </message>
-    <message>
-        <source>Pentobi Help</source>
-        <translation type="vanished">Pentobi-hjelp</translation>
-    </message>
-    <message>
-        <source>New</source>
-        <translation type="vanished">Ny</translation>
-    </message>
-    <message>
-        <source>Rated Game</source>
-        <translation type="vanished">Vurdert spill</translation>
-    </message>
-    <message>
-        <source>Open…</source>
-        <translation type="vanished">Åpne…</translation>
-    </message>
-    <message>
-        <source>Play</source>
-        <translation type="vanished">Spill</translation>
-    </message>
-    <message>
-        <source>Play Move</source>
-        <extracomment>Play a single move</extracomment>
-        <translation type="vanished">Spill enkelt trekk</translation>
-    </message>
-    <message>
-        <source>Quit</source>
-        <translation type="vanished">Avslutt</translation>
-    </message>
-    <message>
-        <source>Save</source>
-        <translation type="vanished">Lagre</translation>
-    </message>
-    <message>
-        <source>Save As…</source>
-        <translation type="vanished">Lagre som…</translation>
-    </message>
-    <message>
-        <source>Stop</source>
-        <translation type="vanished">Stopp</translation>
-    </message>
-    <message>
-        <source>Undo Move</source>
-        <translation type="vanished">Angre trekk</translation>
-    </message>
-    <message>
-        <source>Game Info</source>
-        <translation type="vanished">Spillinfo</translation>
-    </message>
-    <message>
-        <source>Comment</source>
-        <translation type="vanished">Kommentar</translation>
-    </message>
-    <message>
-        <source>Settings</source>
-        <extracomment>Menu item Computer/Settings</extracomment>
-        <translation type="vanished">Innstillinger</translation>
-    </message>
-</context>
 <context>
     <name>AnalyzeDialog</name>
     <message>
@@ -279,38 +187,6 @@
         <source>Computer plays:</source>
         <translation>Datamaskinen spiller:</translation>
     </message>
-    <message>
-        <source>Blue/Red</source>
-        <translation type="vanished">Blå/rød</translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation type="vanished">Lilla</translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation type="vanished">Grønn</translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation type="vanished">Blå</translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation type="vanished">Gul/grønn</translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation type="vanished">Oransje</translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation type="vanished">Gul</translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation type="vanished">Rød</translation>
-    </message>
     <message>
         <source>Level %1</source>
         <translation>Nivå %1</translation>
@@ -395,38 +271,6 @@
 </context>
 <context>
     <name>GameModel</name>
-    <message>
-        <source>Blue/Red</source>
-        <translation type="vanished">Blå/rød</translation>
-    </message>
-    <message>
-        <source>Purple</source>
-        <translation type="vanished">Lilla</translation>
-    </message>
-    <message>
-        <source>Green</source>
-        <translation type="vanished">Grønn</translation>
-    </message>
-    <message>
-        <source>Blue</source>
-        <translation type="vanished">Blå</translation>
-    </message>
-    <message>
-        <source>Yellow/Green</source>
-        <translation type="vanished">Gul/grønn</translation>
-    </message>
-    <message>
-        <source>Orange</source>
-        <translation type="vanished">Oransje</translation>
-    </message>
-    <message>
-        <source>Yellow</source>
-        <translation type="vanished">Gul</translation>
-    </message>
-    <message>
-        <source>Red</source>
-        <translation type="vanished">Rød</translation>
-    </message>
     <message>
         <source>Purple wins with 1 point.</source>
         <translation>Lilla vinner med ett poeng.</translation>
@@ -1040,7 +884,11 @@
     </message>
     <message>
         <source>Pentobi failed to generate a move.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Press back again to exit</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -1049,31 +897,6 @@
         <source>Computer</source>
         <translation>Datamaskin</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
-        <translation>D</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
 </context>
 <context>
     <name>MenuEdit</name>
@@ -1081,16 +904,6 @@
         <source>Edit</source>
         <translation>Rediger</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
     <message>
         <source>Make Main Variation</source>
         <translation>Gjør til hovedvariasjon</translation>
@@ -1100,93 +913,43 @@
         <extracomment>Short for Move Variation Up</extracomment>
         <translation>Variasjon oppover</translation>
     </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
         <translation>Variasjon nedover</translation>
     </message>
-    <message>
-        <source>W</source>
-        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
     <message>
         <source>Delete Variations</source>
         <translation>Slett variasjoner</translation>
     </message>
-    <message>
-        <source>D</source>
-        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Truncate</source>
         <translation>Forkort</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
     <message>
         <source>Truncate Children</source>
         <translation>Forkort underprosess</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Keep Position</source>
         <translation>Behold posisjon</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
     <message>
         <source>Keep Subtree</source>
         <translation>Behold undertreet</translation>
     </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
     <message>
         <source>Setup Mode</source>
         <translation>Oppsettsmodus</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
     <message>
         <source>Next Color</source>
         <translation>Neste farge</translation>
     </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
     <message>
         <source>Annotation…</source>
         <translation>Anmerkning…</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Made main variation</source>
         <translation>Gjort til hovedvariasjon</translation>
@@ -1198,21 +961,6 @@
         <source>Export</source>
         <translation>Eksporter</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Image…</source>
         <translation>Bilde…</translation>
@@ -1228,74 +976,14 @@
         <source>Game</source>
         <translation>Spil</translation>
     </message>
-    <message>
-        <source>G</source>
-        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Game Variant…</source>
         <translation>Spillvariant…</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>I</source>
-        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>Open Clipboard</source>
         <translation>Åpne utklippstavle</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
-        <translation>L</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>Q</source>
-        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1303,31 +991,6 @@
         <source>Go</source>
         <translation>Gå</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
-        <translation>G</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
 </context>
 <context>
     <name>MenuHelp</name>
@@ -1335,34 +998,14 @@
         <source>Help</source>
         <translation>Hjelp</translation>
     </message>
-    <message>
-        <source>H</source>
-        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>About Pentobi</source>
         <translation>Om Pentobi</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Report Bug</source>
         <translation>Innrapporter feil</translation>
     </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
 </context>
 <context>
     <name>MenuItem</name>
@@ -1383,26 +1026,11 @@
         <source>Open Recent</source>
         <translation>Åpne nylige</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
-        <translation>Y</translation>
-    </message>
-    <message>
-        <source>%1. %2</source>
-        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
-        <translation>%1. %2</translation>
-    </message>
     <message>
         <source>Clear List</source>
         <extracomment>Menu item for clearing the recent files list</extracomment>
         <translation>Tøm liste</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
 </context>
 <context>
     <name>MenuTools</name>
@@ -1410,47 +1038,18 @@
         <source>Tools</source>
         <translation>Verktøy</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
     <message>
         <source>Rating</source>
         <translation>Vurdering</translation>
     </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Clear Rating</source>
         <translation>Fjern vurdering</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>Analyze Game</source>
-        <translation type="vanished">Analyser spill</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Clear Analysis</source>
         <translation>Tøm analyse</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
     <message>
         <source>Analyze Game…</source>
         <translation>Analyser spill…</translation>
@@ -1462,30 +1061,6 @@
         <source>View</source>
         <translation>Vis</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>Appearance…</source>
-        <translation type="vanished">Utseende…</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
-        <translation>K</translation>
-    </message>
     <message>
         <source>Appearance</source>
         <translation>Utseende</translation>
@@ -1494,11 +1069,6 @@
         <source>Toolbar</source>
         <translation>Verktøyslinje</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
 </context>
 <context>
     <name>MoveAnnotationDialog</name>
@@ -1663,44 +1233,9 @@
         <source>Recent development:</source>
         <translation>Nylig utvikling:</translation>
     </message>
-    <message>
-        <source>Game</source>
-        <translation type="vanished">Spil</translation>
-    </message>
-    <message>
-        <source>Result</source>
-        <translation type="vanished">Resultat</translation>
-    </message>
-    <message>
-        <source>Win</source>
-        <extracomment>Result of rated game is a win</extracomment>
-        <translation type="vanished">Vunnet</translation>
-    </message>
-    <message>
-        <source>Loss</source>
-        <extracomment>Result of rated game is a loss</extracomment>
-        <translation type="vanished">Tapt</translation>
-    </message>
-    <message>
-        <source>Tie</source>
-        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
-        <translation type="vanished">Uavgjort</translation>
-    </message>
-    <message>
-        <source>Level</source>
-        <translation type="vanished">Nivå</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation type="vanished">Din farge</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation type="vanished">Dato</translation>
-    </message>
     <message>
         <source>Open Game %1</source>
-        <translation type="vanished">Åpne spill %1</translation>
+        <translation>Åpne spill %1</translation>
     </message>
 </context>
 <context>
@@ -1826,7 +1361,7 @@
     </message>
     <message>
         <source>Open menu</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -1858,7 +1393,7 @@
     <message>
         <source>Set random seed to &lt;n&gt;.</source>
         <extracomment>Description for command line option --seed</extracomment>
-        <translation type="unfinished">Sett tilfeldig seeding til &lt;n&gt;.</translation>
+        <translation>Sett tilfeldig seeding til &lt;n&gt;.</translation>
     </message>
     <message>
         <source>Use &lt;n&gt; threads (0=auto).</source>
@@ -1896,4 +1431,4 @@
         <translation>For mange argumenter</translation>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
