@@ -1,6 +1,4 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.1" language="zh_CN">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="zh_CN" version="2.1">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -548,7 +546,7 @@
     <message>
         <source>Pentobi</source>
         <extracomment>Window title if no file is loaded.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Game analysis is only possible in main variation.</source>
@@ -688,7 +686,7 @@
     <message>
         <source>%1 - Pentobi</source>
         <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Not enough memory</source>
@@ -886,7 +884,11 @@
     </message>
     <message>
         <source>Pentobi failed to generate a move.</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
+    </message>
+    <message>
+        <source>Press back again to exit</source>
+        <translation type="unfinished"/>
     </message>
 </context>
 <context>
@@ -895,31 +897,6 @@
         <source>Computer</source>
         <translation>电脑</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
 </context>
 <context>
     <name>MenuEdit</name>
@@ -927,16 +904,6 @@
         <source>Edit</source>
         <translation>编辑</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
     <message>
         <source>Make Main Variation</source>
         <translation>设为主变例</translation>
@@ -946,93 +913,43 @@
         <extracomment>Short for Move Variation Up</extracomment>
         <translation>上一变例</translation>
     </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
     <message>
         <source>Variation Down</source>
         <extracomment>Short for Move Variation Down</extracomment>
         <translation>下一变例</translation>
     </message>
-    <message>
-        <source>W</source>
-        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
-        <translation>W</translation>
-    </message>
     <message>
         <source>Delete Variations</source>
         <translation>删除所有变例</translation>
     </message>
-    <message>
-        <source>D</source>
-        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
-        <translation>D</translation>
-    </message>
     <message>
         <source>Truncate</source>
         <translation>截断</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
     <message>
         <source>Truncate Children</source>
         <translation>截断子结点</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
     <message>
         <source>Keep Position</source>
         <translation>保存棋子位置</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>Keep Subtree</source>
         <translation>保留子树</translation>
     </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
     <message>
         <source>Setup Mode</source>
         <translation>设置模式</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Next Color</source>
         <translation>轮到的颜色</translation>
     </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
     <message>
         <source>Annotation…</source>
         <translation>注解…</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Made main variation</source>
         <translation>已设为主变例</translation>
@@ -1044,21 +961,6 @@
         <source>Export</source>
         <translation>导出</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Image…</source>
         <translation>图像…</translation>
@@ -1074,74 +976,14 @@
         <source>Game</source>
         <translation>棋局</translation>
     </message>
-    <message>
-        <source>G</source>
-        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
-        <translation>G</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
     <message>
         <source>Game Variant…</source>
         <translation>游戏规则…</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>I</source>
-        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
-        <translation>I</translation>
-    </message>
-    <message>
-        <source>U</source>
-        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
-        <translation>U</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
     <message>
         <source>Open Clipboard</source>
         <translation>打开剪贴板</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
-    <message>
-        <source>S</source>
-        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
-        <translation>S</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>Q</source>
-        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
-        <translation>Q</translation>
-    </message>
 </context>
 <context>
     <name>MenuGo</name>
@@ -1149,31 +991,6 @@
         <source>Go</source>
         <translation>转到</translation>
     </message>
-    <message>
-        <source>O</source>
-        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
-        <translation>O</translation>
-    </message>
-    <message>
-        <source>N</source>
-        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
-        <translation>N</translation>
-    </message>
-    <message>
-        <source>M</source>
-        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
-        <translation>M</translation>
-    </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
 </context>
 <context>
     <name>MenuHelp</name>
@@ -1181,34 +998,14 @@
         <source>Help</source>
         <translation>帮助</translation>
     </message>
-    <message>
-        <source>H</source>
-        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
-        <translation>H</translation>
-    </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
     <message>
         <source>About Pentobi</source>
         <translation>关于</translation>
     </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Report Bug</source>
         <translation>报告bug</translation>
     </message>
-    <message>
-        <source>B</source>
-        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
-        <translation>B</translation>
-    </message>
 </context>
 <context>
     <name>MenuItem</name>
@@ -1229,26 +1026,11 @@
         <source>Open Recent</source>
         <translation>打开最近文件</translation>
     </message>
-    <message>
-        <source>P</source>
-        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
-        <translation>P</translation>
-    </message>
-    <message>
-        <source>%1. %2</source>
-        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
-        <translation>(%1) %2</translation>
-    </message>
     <message>
         <source>Clear List</source>
         <extracomment>Menu item for clearing the recent files list</extracomment>
         <translation>清除列表</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
 </context>
 <context>
     <name>MenuTools</name>
@@ -1256,47 +1038,18 @@
         <source>Tools</source>
         <translation>工具</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
     <message>
         <source>Rating</source>
         <translation>等级分</translation>
     </message>
-    <message>
-        <source>R</source>
-        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
-        <translation>R</translation>
-    </message>
     <message>
         <source>Clear Rating</source>
         <translation>清除等级分</translation>
     </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
-    <message>
-        <source>Analyze Game</source>
-        <translation type="vanished">分析棋局</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
     <message>
         <source>Clear Analysis</source>
         <translation>清除分析</translation>
     </message>
-    <message>
-        <source>E</source>
-        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
-        <translation>E</translation>
-    </message>
     <message>
         <source>Analyze Game…</source>
         <translation>分析棋局…</translation>
@@ -1308,26 +1061,6 @@
         <source>View</source>
         <translation>视图</translation>
     </message>
-    <message>
-        <source>V</source>
-        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
-        <translation>V</translation>
-    </message>
-    <message>
-        <source>A</source>
-        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
-        <translation>A</translation>
-    </message>
-    <message>
-        <source>F</source>
-        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
-        <translation>F</translation>
-    </message>
-    <message>
-        <source>C</source>
-        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
-        <translation>C</translation>
-    </message>
     <message>
         <source>Appearance</source>
         <translation>界面</translation>
@@ -1336,11 +1069,6 @@
         <source>Toolbar</source>
         <translation>工具栏</translation>
     </message>
-    <message>
-        <source>T</source>
-        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
-        <translation>T</translation>
-    </message>
 </context>
 <context>
     <name>MoveAnnotationDialog</name>
@@ -1505,44 +1233,9 @@
         <source>Recent development:</source>
         <translation>最近的发展：</translation>
     </message>
-    <message>
-        <source>Game</source>
-        <translation type="vanished">总局数</translation>
-    </message>
-    <message>
-        <source>Result</source>
-        <translation type="vanished">结果</translation>
-    </message>
-    <message>
-        <source>Win</source>
-        <extracomment>Result of rated game is a win</extracomment>
-        <translation type="vanished">胜</translation>
-    </message>
-    <message>
-        <source>Loss</source>
-        <extracomment>Result of rated game is a loss</extracomment>
-        <translation type="vanished">负</translation>
-    </message>
-    <message>
-        <source>Tie</source>
-        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
-        <translation type="vanished">平</translation>
-    </message>
-    <message>
-        <source>Level</source>
-        <translation type="vanished">级别</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation type="vanished">您执</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation type="vanished">日期</translation>
-    </message>
     <message>
         <source>Open Game %1</source>
-        <translation type="vanished">打开第%1局</translation>
+        <translation>打开第%1局</translation>
     </message>
 </context>
 <context>
@@ -1675,67 +1368,67 @@
     <name>main</name>
     <message>
         <source>computer opponent for the board game Blokus</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Set maximum level to &lt;n&gt;.</source>
         <extracomment>Description for command line option --maxlevel</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Do not use opening books.</source>
         <extracomment>Description for command line option --nobook</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Use layout optimized for smartphones.</source>
         <extracomment>Description for command line option --mobile</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Do not delay fast computer moves.</source>
         <extracomment>Description for command line option --nodelay</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Set random seed to &lt;n&gt;.</source>
         <extracomment>Description for command line option --seed</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Use &lt;n&gt; threads (0=auto).</source>
         <extracomment>Description for command line option --threads</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Print logging information to standard error.</source>
         <extracomment>Description for command line option --verbose</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>file.blksgf</source>
         <extracomment>Name of command line argument.</extracomment>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Blokus SGF file to open (optional).</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>--maxlevel must be between 1 and %1</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>--seed must be a positive number</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>--threads must be a positive number</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
     <message>
         <source>Too many arguments</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished"/>
     </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
